@@ -16,11 +16,11 @@
 
 ##' Class \code{"SIR"}
 ##'
-##' Class to handle the SIR \code{\link{siminf_model}}.
-##' @include siminf_model.R
+##' Class to handle the SIR \code{\link{SimInf_model}}.
+##' @include SimInf_model.R
 ##' @include AllGenerics.R
 ##' @export
-setClass("SIR", contains = c("siminf_model"))
+setClass("SIR", contains = c("SimInf_model"))
 
 ##' Create a SIR model
 ##'
@@ -37,10 +37,9 @@ setClass("SIR", contains = c("siminf_model"))
 ##'
 ##' @param u0 A \code{data.frame} with the initial state in each node,
 ##'     see details.
-##' @param tspan An increasing sequence of points in time where the
-##'     state of the system is to be returned.
+##' @template tspan-param
 ##' @param events a \code{data.frame} with the scheduled events, see
-##'     \code{\link{siminf_model}}.
+##'     \code{\link{SimInf_model}}.
 ##' @param beta The transmission rate from susceptible to infected.
 ##' @param gamma The recovery rate from infected to recovered.
 ##' @return \code{SIR}
@@ -122,7 +121,7 @@ SIR <- function(u0,
     storage.mode(gdata) <- "double"
     names(gdata) <- c("beta", "gamma")
 
-    model <- siminf_model(G      = G,
+    model <- SimInf_model(G      = G,
                           S      = S,
                           E      = E,
                           N      = N,
@@ -148,7 +147,9 @@ setMethod("susceptible",
               if (!is.null(i))
                   ii <- ii[i]
               j <- seq(from = 1, to = dim(model@U)[2], by = by)
-              as.matrix(model@U[ii, j, drop = FALSE])
+              result <- as.matrix(model@U[ii, j, drop = FALSE])
+              rownames(result) <- NULL
+              result
           }
 )
 
@@ -164,7 +165,9 @@ setMethod("infected",
               if (!is.null(i))
                   ii <- ii[i]
               j <- seq(from = 1, to = dim(model@U)[2], by = by)
-              as.matrix(model@U[ii, j, drop = FALSE])
+              result <- as.matrix(model@U[ii, j, drop = FALSE])
+              rownames(result) <- NULL
+              result
           }
 )
 
@@ -180,7 +183,9 @@ setMethod("recovered",
               if (!is.null(i))
                   ii <- ii[i]
               j <- seq(from = 1, to = dim(model@U)[2], by = by)
-              as.matrix(model@U[ii, j, drop = FALSE])
+              result <- as.matrix(model@U[ii, j, drop = FALSE])
+              rownames(result) <- NULL
+              result
           }
 )
 
@@ -190,10 +195,14 @@ setMethod("recovered",
 ##' @export
 setMethod("plot",
           signature(x = "SIR"),
-          function(x, t0 = NULL, ...)
-      {
-          callNextMethod(x, t0 = t0, legend = c("S", "I", "R"), ...)
-      }
+          function(x,
+                   col = c("blue", "red", "darkgreen"),
+                   lty = rep(1, 3),
+                   lwd = 2,
+                   ...)
+          {
+              callNextMethod(x, col = col, lty = lty, lwd = lwd, ...)
+          }
 )
 
 ##' Scheduled events example data for the \code{SIR} model
