@@ -1,7 +1,7 @@
 ## SimInf, a framework for stochastic disease spread simulations
 ## Copyright (C) 2015  Pavol Bauer
-## Copyright (C) 2015 - 2016  Stefan Engblom
-## Copyright (C) 2015 - 2016  Stefan Widgren
+## Copyright (C) 2015 - 2017  Stefan Engblom
+## Copyright (C) 2015 - 2017  Stefan Widgren
 ##
 ## This program is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -34,6 +34,16 @@ NULL
     library.dynam.unload("SimInf", libpath)
 }
 
+##' Is OpenMP available
+##'
+##' @return TRUE if SimInf was built with support for OpenMP, else
+##'     FALSE.
+##' @keywords internal
+have_openmp <- function()
+{
+    .Call(SimInf_have_openmp)
+}
+
 ##' Scheduled events example data
 ##'
 ##' Synthetic scheduled events data to demonstrate the \code{SISe3}
