@@ -1,8 +1,8 @@
 /*
  *  SimInf, a framework for stochastic disease spread simulations
  *  Copyright (C) 2015  Pavol Bauer
- *  Copyright (C) 2015 - 2016  Stefan Engblom
- *  Copyright (C) 2015 - 2016  Stefan Widgren
+ *  Copyright (C) 2015 - 2017  Stefan Engblom
+ *  Copyright (C) 2015 - 2017  Stefan Widgren
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "siminf.h"
+#include "SimInf.h"
 #include "siminf_forward_euler_linear_decay.h"
 
 /* Offset in integer compartment state vector */
@@ -177,8 +177,7 @@ int SISe3_post_time_step(
     const double *ldata,
     const double *gdata,
     int node,
-    double t,
-    gsl_rng *rng)
+    double t)
 {
     const int day = (int)t % 365;
     const double I_n = u[I_1] + u[I_2] + u[I_3];
@@ -218,5 +217,5 @@ SEXP SISe3_run(SEXP model, SEXP threads, SEXP seed)
                       &SISe3_S_2_to_I_2, &SISe3_I_2_to_S_2,
                       &SISe3_S_3_to_I_3, &SISe3_I_3_to_S_3};
 
-    return siminf_run(model, threads, seed, tr_fun, &SISe3_post_time_step);
+    return SimInf_run(model, threads, seed, tr_fun, &SISe3_post_time_step);
 }
