@@ -1,7 +1,7 @@
 ## SimInf, a framework for stochastic disease spread simulations
 ## Copyright (C) 2015  Pavol Bauer
-## Copyright (C) 2015 - 2016  Stefan Engblom
-## Copyright (C) 2015 - 2016  Stefan Widgren
+## Copyright (C) 2015 - 2017  Stefan Engblom
+## Copyright (C) 2015 - 2017  Stefan Widgren
 ##
 ## This program is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -54,7 +54,7 @@ U <- matrix(nrow = 0, ncol = 0)
 storage.mode(U) <- "integer"
 
 ## Check tspan
-res <- tools::assertError(new("siminf_model",
+res <- tools::assertError(new("SimInf_model",
                               G     = G,
                               S     = S,
                               U     = U,
@@ -64,7 +64,7 @@ res <- tools::assertError(new("siminf_model",
 stopifnot(length(grep("Input time-span must be an increasing vector.",
                       res[[1]]$message)) > 0)
 
-res <- tools::assertError(new("siminf_model",
+res <- tools::assertError(new("SimInf_model",
                               G     = G,
                               S     = S,
                               U     = U,
@@ -74,8 +74,33 @@ res <- tools::assertError(new("siminf_model",
 stopifnot(length(grep("Input time-span must be an increasing vector.",
                       res[[1]]$message)) > 0)
 
+res <- tools::assertError(new("SimInf_model",
+                              G     = G,
+                              S     = S,
+                              U     = U,
+                              ldata = matrix(rep(0, Nn), nrow = 1),
+                              tspan = c(1, NA, 3),
+                              u0    = u0))
+stopifnot(length(grep("Input time-span must be an increasing vector.",
+                      res[[1]]$message)) > 0)
+
+## Check that tspan can be a Date vector
+res <- SimInf_model(G     = G,
+                    S     = S,
+                    U     = U,
+                    ldata = matrix(rep(0, Nn), nrow = 1),
+                    tspan = as.Date(c("2017-01-01",
+                                      "2017-01-02",
+                                      "2017-01-03")),
+                    u0    = u0)
+stopifnot(identical(res@tspan,
+                    structure(c(1, 2, 3),
+                              .Names = c("2017-01-01",
+                                         "2017-01-02",
+                                         "2017-01-03"))))
+
 ## Check u0
-res <- tools::assertError(new("siminf_model",
+res <- tools::assertError(new("SimInf_model",
                               G     = G,
                               S     = S,
                               U     = U,
@@ -89,7 +114,7 @@ stopifnot(length(grep("Initial state 'u0' has negative elements.",
 ## Should not raise error
 u0_double <- u0
 storage.mode(u0_double) <- "double"
-siminf_model(G     = G,
+SimInf_model(G     = G,
              S     = S,
              U     = U,
              ldata = matrix(rep(0, Nn), nrow = 1),
@@ -101,7 +126,7 @@ siminf_model(G     = G,
 u0_double <- u0
 storage.mode(u0_double) <- "double"
 u0_double <- 1.2 * u0_double
-res <- tools::assertError(siminf_model(G     = G,
+res <- tools::assertError(SimInf_model(G     = G,
                                        S     = S,
                                        U     = U,
                                        ldata = matrix(rep(0, Nn), nrow = 1),
@@ -111,7 +136,7 @@ stopifnot(length(grep("u0 must be an integer matrix",
                       res[[1]]$message)) > 0)
 
 ## Check S
-res <- tools::assertError(new("siminf_model",
+res <- tools::assertError(new("SimInf_model",
                               G     = G,
                               S     = S * 1.1,
                               U     = U,
@@ -123,7 +148,7 @@ stopifnot(length(grep("'S' matrix must be an integer matrix.",
 
 ## Check G
 ## Error: Wrong size of dependency graph
-res <- tools::assertError(new("siminf_model",
+res <- tools::assertError(new("SimInf_model",
                               G     = G[-1,],
                               S     = S,
                               U     = U,
@@ -134,7 +159,7 @@ stopifnot(length(grep("Wrong size of dependency graph.",
                       res[[1]]$message)) > 0)
 
 ## Check gdata
-res <- tools::assertError(new("siminf_model",
+res <- tools::assertError(new("SimInf_model",
                               G     = G,
                               S     = S,
                               U     = U,
@@ -150,7 +175,7 @@ ldata <- matrix(rep(0, Nn), nrow = 1)
 ldata <- ldata[, 1:3, drop = FALSE]
 
 ## Wrong size of ldata matrix
-res <- tools::assertError(new("siminf_model",
+res <- tools::assertError(new("SimInf_model",
                               G     = G,
                               S     = S,
                               U     = U,
@@ -171,7 +196,7 @@ u0 <- structure(list(S_1 = c(0, 1, 2, 3, 4, 5),
                 row.names = c(NA, -6L), class = "data.frame")
 
 ## 'u0' is NULL
-res <- tools::assertError(siminf_model())
+res <- tools::assertError(SimInf_model())
 stopifnot(length(grep("'u0' is NULL",
                       res[[1]]$message)) > 0)
 
@@ -319,7 +344,7 @@ U <- structure(c(0L, 0L, 0L, 0L, 0L, 0L, 0L, 1L, 1L, 0L, 1L, 0L, 2L, 0L, 1L, 1L,
 U_double <- U
 storage.mode(U_double) <- "double"
 
-siminf_model(G     = G,
+SimInf_model(G     = G,
              S     = S,
              U     = U_double,
              ldata = matrix(rep(0, Nn), nrow = 1),
@@ -332,7 +357,7 @@ U_double <- U
 storage.mode(U_double) <- "double"
 U_double <- U_double * 1.2
 
-res <- tools::assertError(siminf_model(G     = G,
+res <- tools::assertError(SimInf_model(G     = G,
                                        S     = S,
                                        U     = U_double,
                                        ldata = matrix(rep(0, Nn), nrow = 1),
@@ -342,7 +367,7 @@ stopifnot(length(grep("U must be an integer",
                       res[[1]]$message)) > 0)
 
 ## Check U. Should not raise an error if U is an integer vector of length 0
-siminf_model(G     = G,
+SimInf_model(G     = G,
              S     = S,
              U     = integer(0),
              ldata = matrix(rep(0, Nn), nrow = 1),
@@ -350,7 +375,7 @@ siminf_model(G     = G,
              u0    = u0)
 
 ## Check U. Should raise error if U is an integer vector of length > 0
-res <- tools::assertError(siminf_model(G     = G,
+res <- tools::assertError(SimInf_model(G     = G,
                                        S     = S,
                                        U     = c(1L),
                                        ldata = matrix(rep(0, Nn), nrow = 1),
@@ -370,7 +395,7 @@ V <- structure(c(1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
 V_integer <- V
 storage.mode(V) <- "integer"
 
-siminf_model(G     = G,
+SimInf_model(G     = G,
              S     = S,
              U     = U,
              V     = V_integer,
@@ -383,7 +408,7 @@ siminf_model(G     = G,
 V_character <- V
 storage.mode(V_character) <- "character"
 
-res <- tools::assertError(siminf_model(G     = G,
+res <- tools::assertError(SimInf_model(G     = G,
                                        S     = S,
                                        U     = U,
                                        V     = V_character,
@@ -394,7 +419,7 @@ stopifnot(length(grep("V must be numeric",
                       res[[1]]$message)) > 0)
 
 ## Check V. Should raise error if V is a vector of length > 0
-res <- tools::assertError(siminf_model(G     = G,
+res <- tools::assertError(SimInf_model(G     = G,
                                        S     = S,
                                        U     = U,
                                        V     = 1,
@@ -405,7 +430,7 @@ stopifnot(length(grep("V must be equal to 0 x 0 matrix",
                       res[[1]]$message)) > 0)
 
 ## Check V. Should not raise an error if V is an integer vector of length 0
-siminf_model(G     = G,
+SimInf_model(G     = G,
              S     = S,
              U     = U,
              V     = integer(0),
@@ -417,3 +442,99 @@ siminf_model(G     = G,
 res <- tools::assertError(plot(demo_model()))
 stopifnot(length(grep("Please run the model first, the 'U' matrix is empty",
                       res[[1]]$message)) > 0)
+
+## Check that the SimInf_model initialisation fails if the events
+## argument is not either NULL or a data.frame
+u0 <- structure(list(S_1 = c(0, 1, 2, 3, 4, 5),
+                     I_1 = c(0, 0, 0, 0, 0, 0),
+                     S_2 = c(0, 1, 2, 3, 4, 5),
+                     I_2 = c(0, 0, 0, 0, 0, 0),
+                     S_3 = c(0, 1, 2, 3, 4, 5),
+                     I_3 = c(0, 0, 0, 0, 0, 0)),
+                .Names = c("S_1", "I_1", "S_2", "I_2", "S_3", "I_3"),
+                row.names = c(NA, -6L),
+                class = "data.frame")
+
+res <- tools::assertError(model <- SISe3(u0        = u0,
+                                         tspan     = 0:10,
+                                         events    = "events",
+                                         phi       = rep(1, 6),
+                                         upsilon_1 = 1,
+                                         upsilon_2 = 1,
+                                         upsilon_3 = 1,
+                                         gamma_1   = 1,
+                                         gamma_2   = 1,
+                                         gamma_3   = 1,
+                                         alpha     = 1,
+                                         beta_t1   = 1,
+                                         beta_t2   = 1,
+                                         beta_t3   = 1,
+                                         beta_t4   = 1,
+                                         end_t1    = 91,
+                                         end_t2    = 182,
+                                         end_t3    = 273,
+                                         end_t4    = 365,
+                                         epsilon   = 1))
+stopifnot(length(grep("'events' must be NULL or a data.frame",
+                      res[[1]]$message)) > 0)
+
+## Check that tspan names are copied to U and V colnames
+model <- SIR(u0 = data.frame(S = 99, I = 1, R = 0),
+             tspan = 1:10,
+             beta = 0.16,
+             gamma = 0.077)
+result <- run(model, threads = 1)
+stopifnot(is.null(colnames(U(result))))
+stopifnot(is.null(colnames(V(result))))
+
+tspan <- seq(as.Date("2016-01-01"), as.Date("2016-01-10"), by = 1)
+model <- SIR(u0 = data.frame(S = 99, I = 1, R = 0),
+             tspan = tspan,
+             beta = 0.16,
+             gamma = 0.077)
+result <- run(model, threads = 1)
+stopifnot(identical(colnames(U(result)), as.character(tspan)))
+stopifnot(identical(colnames(V(result)), as.character(tspan)))
+
+u0 <- data.frame(S = 100:105, I = 1:6)
+model <- SISe(u0 = u0, tspan = 1:10,
+              phi = rep(0, 6),
+              upsilon = 0.017,
+              gamma   = 0.1,
+              alpha   = 1,
+              beta_t1 = 0.19,
+              beta_t2 = 0.085,
+              beta_t3 = 0.075,
+              beta_t4 = 0.185,
+              end_t1  = 91,
+              end_t2  = 182,
+              end_t3  = 273,
+              end_t4  = 365,
+              epsilon = 0.000011)
+U(model) <- Matrix::sparseMatrix(1:6, 5:10, dims = c(12, 10))
+V(model) <- Matrix::sparseMatrix(1:6, 5:10)
+result <- run(model, threads = 1)
+stopifnot(is.null(colnames(U(result))))
+stopifnot(is.null(colnames(V(result))))
+
+tspan <- seq(as.Date("2016-01-01"), as.Date("2016-01-10"), by = 1)
+u0 <- data.frame(S = 100:105, I = 1:6)
+model <- SISe(u0 = u0, tspan = tspan,
+              phi = rep(0, 6),
+              upsilon = 0.017,
+              gamma   = 0.1,
+              alpha   = 1,
+              beta_t1 = 0.19,
+              beta_t2 = 0.085,
+              beta_t3 = 0.075,
+              beta_t4 = 0.185,
+              end_t1  = 91,
+              end_t2  = 182,
+              end_t3  = 273,
+              end_t4  = 365,
+              epsilon = 0.000011)
+U(model) <- Matrix::sparseMatrix(1:6, 5:10, dims = c(12, 10))
+V(model) <- Matrix::sparseMatrix(1:6, 5:10)
+result <- run(model, threads = 1)
+stopifnot(identical(colnames(U(result)), as.character(tspan)))
+stopifnot(identical(colnames(V(result)), as.character(tspan)))
